pub fn need_auth(path: &str, include: &[&str], exclude: &[&str]) -> boolExpand description
Determine if authentication is needed for a path 判断路径是否需要鉴权
Returns true if path matches include patterns but not exclude patterns
如果路径匹配包含模式但不匹配排除模式,返回 true